==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1CinderVolumeSourceFluent.java <==
package io.kubernetes.client.models;

import java.lang.Deprecated;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Boolean;

public interface V1CinderVolumeSourceFluent<A extends V1CinderVolumeSourceFluent<A>> extends Fluent<A>{


    public String getFsType();
    public A withFsType(String fsType);
    public Boolean hasFsType();
    public Boolean isReadOnly();
    public A withReadOnly(Boolean readOnly);
    public Boolean hasReadOnly();
    public A withNewReadOnly(boolean arg1);
    public A withNewReadOnly(String arg1);
    
/**
 * This method has been deprecated, please use method buildSecretRef instead.
 * @return The buildable object.
 */
@Deprecated public V1LocalObjectReference getSecretRef();
    public V1LocalObjectReference buildSecretRef();
    public A withSecretRef(V1LocalObjectReference secretRef);
    public Boolean hasSecretRef();
    public V1CinderVolumeSourceFluent.SecretRefNested<A> withNewSecretRef();
    public V1CinderVolumeSourceFluent.SecretRefNested<A> withNewSecretRefLike(V1LocalObjectReference item);
    public V1CinderVolumeSourceFluent.SecretRefNested<A> editSecretRef();
    public V1CinderVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRef();
    public V1CinderVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRefLike(V1LocalObjectReference item);
    public String getVolumeID();
    public A withVolumeID(String volumeID);
    public Boolean hasVolumeID();

    public interface SecretRefNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1LocalObjectReferenceFluent<V1CinderVolumeSourceFluent.SecretRefNested<N>>{

        
    public N and();    public N endSecretRef();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1CinderVolumeSourceFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V1CinderVolumeSourceFluent<A extends V1CinderVolumeSourceFluent<A>> extends Fluent<A>{


    public String getFsType();
    public A withFsType(String fsType);
    public Boolean hasFsType();
    public A withNewFsType(String arg1);
    public A withNewFsType(StringBuilder arg1);
    public A withNewFsType(StringBuffer arg1);
    public Boolean isReadOnly();
    public A withReadOnly(Boolean readOnly);
    public Boolean hasReadOnly();
    public A withNewReadOnly(String arg1);
    public A withNewReadOnly(boolean arg1);
    
/**
 * This method has been deprecated, please use method buildSecretRef instead.
 * @return The buildable object.
 */
@Deprecated public V1LocalObjectReference getSecretRef();
    public V1LocalObjectReference buildSecretRef();
    public A withSecretRef(V1LocalObjectReference secretRef);
    public Boolean hasSecretRef();
    public V1CinderVolumeSourceFluent.SecretRefNested<A> withNewSecretRef();
    public V1CinderVolumeSourceFluent.SecretRefNested<A> withNewSecretRefLike(V1LocalObjectReference item);
    public V1CinderVolumeSourceFluent.SecretRefNested<A> editSecretRef();
    public V1CinderVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRef();
    public V1CinderVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRefLike(V1LocalObjectReference item);
    public String getVolumeID();
    public A withVolumeID(String volumeID);
    public Boolean hasVolumeID();
    public A withNewVolumeID(String arg1);
    public A withNewVolumeID(StringBuilder arg1);
    public A withNewVolumeID(StringBuffer arg1);

    public interface SecretRefNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1LocalObjectReferenceFluent<V1CinderVolumeSourceFluent.SecretRefNested<N>>{

        
    public N and();    public N endSecretRef();
}


}
